# aimet-ml


[![pypi](https://img.shields.io/pypi/v/aimet-ml.svg)](https://pypi.org/project/aimet-ml/)
[![python](https://img.shields.io/pypi/pyversions/aimet-ml.svg)](https://pypi.org/project/aimet-ml/)
[![Build Status](https://github.com/aimet-tech/aimet-ml/actions/workflows/dev.yml/badge.svg)](https://github.com/aimet-tech/aimet-ml/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/aimet-tech/aimet-ml/branch/main/graphs/badge.svg)](https://codecov.io/github/aimet-tech/aimet-ml)



Python package of frequently used modules for ML developments in AIMET.


* Documentation: <https://aimet-tech.github.io/aimet-ml>
* GitHub: <https://github.com/aimet-tech/aimet-ml>
* PyPI: <https://pypi.org/project/aimet-ml/>
* Free software: MIT


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.
